pub struct ConnectionEnv { /* private fields */ }Expand description
Connection-scoped environment for selecting the runtime context.
Implementations
Sourceimpl ConnectionEnv
impl ConnectionEnv
Sourcepub fn new(runtime: Arc<RuntimeContext>) -> Self
pub fn new(runtime: Arc<RuntimeContext>) -> Self
Create a connection environment from an explicit runtime context.
Sourcepub fn runtime(&self) -> &Arc<RuntimeContext>
pub fn runtime(&self) -> &Arc<RuntimeContext>
Access the runtime context that will back newly opened connections.