HotPathProfileSnapshot

Struct HotPathProfileSnapshot 

pub struct HotPathProfileSnapshot {
Show 161 fields pub parser: ParserHotPathProfileSnapshot, pub background_status_time_ns: u64, pub background_status_checks: u64, pub op_cx_background_gates: u64, pub statement_dispatch_background_gates: u64, pub prepared_lookup_time_ns: u64, pub prepared_schema_refresh_time_ns: u64, pub prepared_schema_refreshes: u64, pub prepared_schema_lightweight_refreshes: u64, pub prepared_schema_full_reloads: u64, pub pager_publication_refreshes: u64, pub memory_autocommit_fast_path_begins: u64, pub cached_read_snapshot_reuses: u64, pub cached_read_snapshot_parks: u64, pub begin_setup_time_ns: u64, pub begin_refresh_count: u64, pub commit_refresh_count: u64, pub memdb_refresh_count: u64, pub execute_body_time_ns: u64, pub direct_write_flush_calls: u64, pub direct_write_flush_time_ns: u64, pub commit_pre_txn_time_ns: u64, pub commit_txn_roundtrip_time_ns: u64, pub commit_finalize_seq_time_ns: u64, pub commit_handle_finalize_time_ns: u64, pub commit_post_write_maintenance_time_ns: u64, pub finalize_post_publish_time_ns: u64, pub concurrent_commit_plan_attempts: u64, pub concurrent_commit_plan_successes: u64, pub concurrent_commit_plan_errors: u64, pub concurrent_commit_plan_busy_snapshot_errors: u64, pub concurrent_commit_plan_pending_pages: u64, pub concurrent_commit_plan_write_pages: u64, pub concurrent_commit_plan_held_lock_pages: u64, pub concurrent_commit_plan_uncontended_fast_paths: u64, pub concurrent_commit_plan_candidate_free_fast_paths: u64, pub concurrent_commit_plan_full_validations: u64, pub pager_commit: PagerCommitProfileSnapshot, pub cached_write_txn_reuses: u64, pub cached_write_txn_parks: u64, pub retained_autocommit_reuses: u64, pub retained_autocommit_parks: u64, pub retained_autocommit_flushes: u64, pub retained_autocommit_read_after_write_flushes: u64, pub retained_autocommit_overlay_hits: u64, pub retained_autocommit_overlay_misses: u64, pub column_default_evaluation_passes: u64, pub prepared_table_engine_fresh_allocs: u64, pub prepared_table_engine_reuses: u64, pub prepared_insert_fast_lane_hits: u64, pub prepared_insert_instrumented_lane_hits: u64, pub prepared_update_delete_fast_lane_hits: u64, pub prepared_update_delete_instrumented_lane_hits: u64, pub prepared_update_delete_fallback_returning: u64, pub prepared_update_delete_fallback_sqlite_sequence: u64, pub prepared_update_delete_fallback_without_rowid: u64, pub prepared_update_delete_fallback_live_vtab: u64, pub prepared_update_delete_fallback_trigger: u64, pub prepared_update_delete_fallback_foreign_key: u64, pub prepared_update_delete_dml_direct_handoff_runs: u64, pub prepared_table_dml_affected_only_runs: u64, pub autoincrement_sequence_fast_path_updates: u64, pub autoincrement_sequence_scan_refreshes: u64, pub direct_indexed_equality_query_hits: u64, pub direct_rowid_lookup_query_hits: u64, pub direct_rowid_range_query_hits: u64, pub direct_count_star_query_row_hits: u64, pub direct_rowid_lookup_query_row_hits: u64, pub direct_count_star_rowid_range_query_row_hits: u64, pub direct_count_indexed_rowid_probe_query_row_hits: u64, pub prepared_direct_insert_executions: u64, pub prepared_direct_update_executions: u64, pub prepared_direct_delete_executions: u64, pub prepared_direct_update_leaf_patch_run_start_attempts: u64, pub prepared_direct_update_leaf_patch_run_start_hits: u64, pub prepared_direct_update_leaf_patch_run_start_time_ns: u64, pub prepared_direct_update_leaf_patch_run_active_attempts: u64, pub prepared_direct_update_leaf_patch_run_active_hits: u64, pub prepared_direct_update_leaf_patch_run_active_misses: u64, pub prepared_direct_update_leaf_patch_run_active_time_ns: u64, pub prepared_direct_update_leaf_patch_run_flushes: u64, pub prepared_direct_update_leaf_patch_run_dirty_flushes: u64, pub prepared_direct_update_leaf_patch_run_flush_time_ns: u64, pub prepared_direct_delete_leaf_run_start_attempts: u64, pub prepared_direct_delete_leaf_run_start_hits: u64, pub prepared_direct_delete_leaf_run_start_time_ns: u64, pub prepared_direct_delete_leaf_run_active_attempts: u64, pub prepared_direct_delete_leaf_run_active_hits: u64, pub prepared_direct_delete_leaf_run_active_misses: u64, pub prepared_direct_delete_leaf_run_active_miss_shape_mismatches: u64, pub prepared_direct_delete_leaf_run_active_miss_staged_runs: u64, pub prepared_direct_delete_leaf_run_active_miss_rowid_not_in_leaf: u64, pub prepared_direct_delete_leaf_run_active_miss_already_deleted: u64, pub prepared_direct_delete_leaf_run_active_miss_nonroot_would_empty_leaf: u64, pub prepared_direct_delete_leaf_run_active_miss_nonroot_last_cell: u64, pub prepared_direct_delete_leaf_run_active_miss_noncompact_cell_area: u64, pub prepared_direct_delete_leaf_run_active_miss_cell_shape_or_overflow: u64, pub prepared_direct_delete_leaf_run_active_time_ns: u64, pub prepared_direct_delete_leaf_run_flushes: u64, pub prepared_direct_delete_leaf_run_dirty_flushes: u64, pub prepared_direct_delete_leaf_run_flush_time_ns: u64, pub prepared_direct_delete_preflush_time_ns: u64, pub prepared_direct_delete_rowid_lookup_time_ns: u64, pub prepared_direct_delete_active_leaf_probe_time_ns: u64, pub prepared_direct_delete_cursor_setup_time_ns: u64, pub prepared_direct_delete_memdb_abandon_calls: u64, pub prepared_direct_delete_memdb_abandon_time_ns: u64, pub prepared_direct_delete_memory_sync_calls: u64, pub prepared_direct_delete_memory_sync_time_ns: u64, pub prepared_direct_delete_qf_time_ns: u64, pub prepared_direct_delete_seek_time_ns: u64, pub prepared_direct_delete_physical_delete_time_ns: u64, pub prepared_direct_insert_row_build_time_ns: u64, pub prepared_direct_insert_preserialize_time_ns: u64, pub prepared_direct_insert_preserialize_cell_time_ns: u64, pub prepared_direct_insert_preserialize_eval_time_ns: u64, pub prepared_direct_insert_preserialize_affinity_time_ns: u64, pub prepared_direct_insert_preserialize_layout_time_ns: u64, pub prepared_direct_insert_preserialize_encode_time_ns: u64, pub prepared_direct_insert_row_value_build_time_ns: u64, pub prepared_direct_insert_cursor_setup_time_ns: u64, pub prepared_direct_insert_serialize_time_ns: u64, pub prepared_direct_insert_btree_insert_time_ns: u64, pub prepared_direct_insert_memdb_apply_time_ns: u64, pub prepared_direct_insert_schema_validation_time_ns: u64, pub prepared_direct_insert_autocommit_begin_time_ns: u64, pub prepared_direct_insert_change_tracking_time_ns: u64, pub prepared_direct_insert_autocommit_resolve_time_ns: u64, pub prepared_direct_insert_autocommit_executions: u64, pub prepared_direct_insert_page_run_flushes: u64, pub prepared_direct_insert_page_run_records: u64, pub prepared_direct_insert_page_run_bytes: u64, pub prepared_direct_insert_page_run_owned_flushes: u64, pub prepared_direct_insert_page_run_arena_flushes: u64, pub prepared_direct_insert_page_run_repeated_flushes: u64, pub prepared_direct_insert_page_run_empty_root_bulk_load_hits: u64, pub prepared_direct_insert_page_run_depth2_bulk_append_hits: u64, pub prepared_direct_insert_page_run_row_append_fallback_flushes: u64, pub prepared_direct_insert_page_run_row_append_fallback_rows: u64, pub arena_alloc_bytes: u64, pub arena_reset_count: u64, pub fallback_to_general_allocator_count: u64, pub page_buffer_pool_hits: u64, pub page_buffer_pool_misses: u64, pub window_func_partitions_total: u64, pub statement_global_executions: u64, pub statement_reuse_count: u64, pub statement_reuse_distance_sum: u64, pub statement_max_reuse_distance: u64, pub statement_lane_local_reuses: u64, pub statement_cross_lane_reuses: u64, pub statement_first_hit_count: u64, pub statement_first_hit_time_ns: u64, pub statement_warmed_hit_count: u64, pub statement_warmed_hit_time_ns: u64, pub background_compile_interference_count: u64, pub background_compile_interference_time_ns: u64, pub btree_copy_kernels: BtreeCopyProfileSnapshot, pub btree_leaf_reuse: BtreeLeafReuseSnapshot, pub record_decode: RecordHotPathProfileSnapshot, pub vdbe: VdbeMetricsSnapshot,
}

Fields

parser: ParserHotPathProfileSnapshotbackground_status_time_ns: u64background_status_checks: u64op_cx_background_gates: u64statement_dispatch_background_gates: u64prepared_lookup_time_ns: u64prepared_schema_refresh_time_ns: u64prepared_schema_refreshes: u64prepared_schema_lightweight_refreshes: u64prepared_schema_full_reloads: u64pager_publication_refreshes: u64memory_autocommit_fast_path_begins: u64cached_read_snapshot_reuses: u64cached_read_snapshot_parks: u64begin_setup_time_ns: u64begin_refresh_count: u64

bd-db300.5.2.2.1: Times autocommit-begin did refresh work.

commit_refresh_count: u64

bd-db300.5.2.2.1: Times autocommit-commit did publication refresh.

memdb_refresh_count: u64

bd-db300.5.2.2.1: Times memdb-from-pager refresh was executed (not skipped).

execute_body_time_ns: u64direct_write_flush_calls: u64direct_write_flush_time_ns: u64commit_pre_txn_time_ns: u64commit_txn_roundtrip_time_ns: u64commit_finalize_seq_time_ns: u64commit_handle_finalize_time_ns: u64commit_post_write_maintenance_time_ns: u64finalize_post_publish_time_ns: u64concurrent_commit_plan_attempts: u64concurrent_commit_plan_successes: u64concurrent_commit_plan_errors: u64concurrent_commit_plan_busy_snapshot_errors: u64concurrent_commit_plan_pending_pages: u64concurrent_commit_plan_write_pages: u64concurrent_commit_plan_held_lock_pages: u64concurrent_commit_plan_uncontended_fast_paths: u64concurrent_commit_plan_candidate_free_fast_paths: u64concurrent_commit_plan_full_validations: u64pager_commit: PagerCommitProfileSnapshotcached_write_txn_reuses: u64cached_write_txn_parks: u64retained_autocommit_reuses: u64retained_autocommit_parks: u64retained_autocommit_flushes: u64retained_autocommit_read_after_write_flushes: u64retained_autocommit_overlay_hits: u64retained_autocommit_overlay_misses: u64column_default_evaluation_passes: u64prepared_table_engine_fresh_allocs: u64prepared_table_engine_reuses: u64prepared_insert_fast_lane_hits: u64prepared_insert_instrumented_lane_hits: u64prepared_update_delete_fast_lane_hits: u64prepared_update_delete_instrumented_lane_hits: u64prepared_update_delete_fallback_returning: u64prepared_update_delete_fallback_sqlite_sequence: u64prepared_update_delete_fallback_without_rowid: u64prepared_update_delete_fallback_live_vtab: u64prepared_update_delete_fallback_trigger: u64prepared_update_delete_fallback_foreign_key: u64prepared_update_delete_dml_direct_handoff_runs: u64prepared_table_dml_affected_only_runs: u64autoincrement_sequence_fast_path_updates: u64autoincrement_sequence_scan_refreshes: u64direct_indexed_equality_query_hits: u64direct_rowid_lookup_query_hits: u64

Multi-row query/query_with_params hits on the rowid-lookup lane.

bd-lcz7b: record_query_hit historically ignored SimpleRowidLookup, so the lane was invisible on the query path even when engaged — the bd-dqdoe read attribution misread that blind spot as a missed lane.

direct_rowid_range_query_hits: u64direct_count_star_query_row_hits: u64direct_rowid_lookup_query_row_hits: u64direct_count_star_rowid_range_query_row_hits: u64direct_count_indexed_rowid_probe_query_row_hits: u64prepared_direct_insert_executions: u64prepared_direct_update_executions: u64prepared_direct_delete_executions: u64prepared_direct_update_leaf_patch_run_start_attempts: u64prepared_direct_update_leaf_patch_run_start_hits: u64prepared_direct_update_leaf_patch_run_start_time_ns: u64prepared_direct_update_leaf_patch_run_active_attempts: u64prepared_direct_update_leaf_patch_run_active_hits: u64prepared_direct_update_leaf_patch_run_active_misses: u64prepared_direct_update_leaf_patch_run_active_time_ns: u64prepared_direct_update_leaf_patch_run_flushes: u64prepared_direct_update_leaf_patch_run_dirty_flushes: u64prepared_direct_update_leaf_patch_run_flush_time_ns: u64prepared_direct_delete_leaf_run_start_attempts: u64prepared_direct_delete_leaf_run_start_hits: u64prepared_direct_delete_leaf_run_start_time_ns: u64prepared_direct_delete_leaf_run_active_attempts: u64prepared_direct_delete_leaf_run_active_hits: u64prepared_direct_delete_leaf_run_active_misses: u64prepared_direct_delete_leaf_run_active_miss_shape_mismatches: u64prepared_direct_delete_leaf_run_active_miss_staged_runs: u64prepared_direct_delete_leaf_run_active_miss_rowid_not_in_leaf: u64prepared_direct_delete_leaf_run_active_miss_already_deleted: u64prepared_direct_delete_leaf_run_active_miss_nonroot_would_empty_leaf: u64prepared_direct_delete_leaf_run_active_miss_nonroot_last_cell: u64prepared_direct_delete_leaf_run_active_miss_noncompact_cell_area: u64prepared_direct_delete_leaf_run_active_miss_cell_shape_or_overflow: u64prepared_direct_delete_leaf_run_active_time_ns: u64prepared_direct_delete_leaf_run_flushes: u64prepared_direct_delete_leaf_run_dirty_flushes: u64prepared_direct_delete_leaf_run_flush_time_ns: u64prepared_direct_delete_preflush_time_ns: u64prepared_direct_delete_rowid_lookup_time_ns: u64prepared_direct_delete_active_leaf_probe_time_ns: u64prepared_direct_delete_cursor_setup_time_ns: u64prepared_direct_delete_memdb_abandon_calls: u64prepared_direct_delete_memdb_abandon_time_ns: u64prepared_direct_delete_memory_sync_calls: u64prepared_direct_delete_memory_sync_time_ns: u64prepared_direct_delete_qf_time_ns: u64prepared_direct_delete_seek_time_ns: u64prepared_direct_delete_physical_delete_time_ns: u64prepared_direct_insert_row_build_time_ns: u64prepared_direct_insert_preserialize_time_ns: u64prepared_direct_insert_preserialize_cell_time_ns: u64prepared_direct_insert_preserialize_eval_time_ns: u64prepared_direct_insert_preserialize_affinity_time_ns: u64prepared_direct_insert_preserialize_layout_time_ns: u64prepared_direct_insert_preserialize_encode_time_ns: u64prepared_direct_insert_row_value_build_time_ns: u64prepared_direct_insert_cursor_setup_time_ns: u64prepared_direct_insert_serialize_time_ns: u64prepared_direct_insert_btree_insert_time_ns: u64prepared_direct_insert_memdb_apply_time_ns: u64prepared_direct_insert_schema_validation_time_ns: u64prepared_direct_insert_autocommit_begin_time_ns: u64prepared_direct_insert_change_tracking_time_ns: u64prepared_direct_insert_autocommit_resolve_time_ns: u64prepared_direct_insert_autocommit_executions: u64prepared_direct_insert_page_run_flushes: u64prepared_direct_insert_page_run_records: u64prepared_direct_insert_page_run_bytes: u64prepared_direct_insert_page_run_owned_flushes: u64prepared_direct_insert_page_run_arena_flushes: u64prepared_direct_insert_page_run_repeated_flushes: u64prepared_direct_insert_page_run_empty_root_bulk_load_hits: u64prepared_direct_insert_page_run_depth2_bulk_append_hits: u64prepared_direct_insert_page_run_row_append_fallback_flushes: u64prepared_direct_insert_page_run_row_append_fallback_rows: u64arena_alloc_bytes: u64arena_reset_count: u64fallback_to_general_allocator_count: u64page_buffer_pool_hits: u64page_buffer_pool_misses: u64window_func_partitions_total: u64statement_global_executions: u64

Total statement executions tracked (global sequence counter).

statement_reuse_count: u64

Number of statement reuse events (statement executed again).

statement_reuse_distance_sum: u64

Sum of reuse distances (divide by reuse_count for average).

statement_max_reuse_distance: u64

Maximum observed reuse distance.

statement_lane_local_reuses: u64

Reuses on the same thread (lane-local).

statement_cross_lane_reuses: u64

Reuses on a different thread (cross-lane).

statement_first_hit_count: u64

Count of first-hit statement executions (cache miss requiring parse+compile).

statement_first_hit_time_ns: u64

Total time (ns) for first-hit statement executions.

statement_warmed_hit_count: u64

Count of warmed-hit statement executions (cache hit, reusing compiled plan).

statement_warmed_hit_time_ns: u64

Total time (ns) for warmed-hit statement executions.

background_compile_interference_count: u64

Times foreground was blocked waiting for background compile.

background_compile_interference_time_ns: u64

Time (ns) spent waiting for background compile.

btree_copy_kernels: BtreeCopyProfileSnapshotbtree_leaf_reuse: BtreeLeafReuseSnapshotrecord_decode: RecordHotPathProfileSnapshotvdbe: VdbeMetricsSnapshot