pub struct ParserHotPathProfileSnapshot {Show 15 fields
pub parse_single_calls: u64,
pub parse_multi_calls: u64,
pub parse_cache_hits: u64,
pub parse_cache_misses: u64,
pub parsed_sql_bytes: u64,
pub parse_time_ns: u64,
pub rewrite_calls: u64,
pub rewrite_time_ns: u64,
pub compiled_cache_hits: u64,
pub compiled_cache_misses: u64,
pub prepared_cache_hits: u64,
pub prepared_cache_misses: u64,
pub compile_time_ns: u64,
pub fast_path_executions: u64,
pub slow_path_executions: u64,
}Fields
parse_single_calls: u64parse_multi_calls: u64parse_cache_hits: u64parse_cache_misses: u64parsed_sql_bytes: u64parse_time_ns: u64rewrite_calls: u64rewrite_time_ns: u64compiled_cache_hits: u64compiled_cache_misses: u64prepared_cache_hits: u64prepared_cache_misses: u64compile_time_ns: u64fast_path_executions: u64bd-6eyrg.1: Number of prepared executions that took the fast path.
slow_path_executions: u64bd-6eyrg.1: Number of prepared executions that took the slow path.