AntiEntropySession

Struct AntiEntropySession 

pub struct AntiEntropySession { /* private fields */ }
Anti-entropy session between two replicas.

Implementations

Source

impl AntiEntropySession

pub fn new() -> Self

Create a new anti-entropy session.

pub const fn phase(&self) -> AntiEntropyPhase

Current phase.

pub fn exchange_tips( &mut self, local: ReplicaTip, remote: ReplicaTip, ) -> Result<()>

Step 1: Set local and remote tips.

pub fn compute_missing( &mut self, local_objects: &BTreeSet<ObjectId>, remote_objects: &BTreeSet<ObjectId>, ) -> Result<&MissingObjects>

Step 2: Compute missing objects from local and remote object sets.

pub fn objects_to_request(&self) -> Option<&BTreeSet<ObjectId>>

Step 3: Return the set of object IDs we need symbols for.

pub fn record_decoded(&mut self, object_id: ObjectId) -> Result<()>

Step 4: Record that we received enough symbols and decoded an object.

pub fn finalize(&mut self) -> Result<()>

Step 5: Finalize — persist and update local state.

pub const fn is_converged(&self) -> bool

Check if the session has converged.