pub struct CommitDeduplicator { /* private fields */ }Expand description
Tracks replicated commits and suppresses duplicates by idempotency key.
Implementations
Sourceimpl CommitDeduplicator
impl CommitDeduplicator
Sourcepub fn should_accept(&mut self, marker: &CommitMarker) -> bool
pub fn should_accept(&mut self, marker: &CommitMarker) -> bool
Returns true if the marker is new and should be replicated/applied.
Sourcepub fn seen_count(&self) -> usize
pub fn seen_count(&self) -> usize
Number of unique commits seen.