pub struct LrcCodec { /* private fields */ }Expand description
Local Reconstruction Codes codec.
Produces local parity symbols (one per locality group) plus a global parity symbol. Single failures within a group can be repaired locally.
Implementations
Sourceimpl LrcCodec
impl LrcCodec
Sourcepub fn encode(&self, source_data: &[u8], symbol_size: usize) -> LrcEncodeResult
pub fn encode(&self, source_data: &[u8], symbol_size: usize) -> LrcEncodeResult
Encode source data into source symbols + local/global parities.
source_data is split into symbol_size-byte symbols.
Each locality group of r symbols gets a local parity (XOR).
A global parity (XOR of all source symbols) is also computed.
Sourcepub fn repair(
&self,
encode_result: &LrcEncodeResult,
available: &HashMap<u32, Vec<u8>>,
missing: &[u32],
) -> Vec<LrcRepairOutcome>
pub fn repair( &self, encode_result: &LrcEncodeResult, available: &HashMap<u32, Vec<u8>>, missing: &[u32], ) -> Vec<LrcRepairOutcome>
Attempt to repair missing symbols using local and global parities.
available maps symbol index -> data for symbols that are present.
missing lists the indices of symbols that need repair.
Returns the repair outcome.