IdempotencyStore

Struct IdempotencyStore 

pub struct IdempotencyStore { /* private fields */ }
In-memory idempotency store for remote effects.

Implementations

Source

impl IdempotencyStore

pub fn new() -> Self

pub fn register_or_replay( &self, key: IdempotencyKey, computation: &ComputationName, request_bytes: &[u8], outcome: &[u8], ) -> Result<IdempotencyDecision>

Register outcome for (key, computation, request) or replay prior value.

Errors

Returns FrankenError::Internal if the same idempotency key is reused with different request bytes or a different computation name.