pub struct SavepointEntry {
pub name: String,
/* private fields */
}Expand description
A savepoint on the LIFO stack.
RELEASE X commits work since SAVEPOINT X and removes X and all later savepoints. ROLLBACK TO X undoes work since X but leaves X on the stack.
Fields
name: StringUser-visible savepoint name.