pub enum PagerBackend {
Memory(Arc<SimplePager<MemoryVfs>>),
IoUring(Arc<SimplePager<IoUringVfs>>),
Unix(Arc<SimplePager<UnixVfs>>),
}Expand description
Pager backend that dispatches across VFS implementations.
Wraps SimplePager for both in-memory (:memory:) and on-disk
connections without making Connection generic.
Variants
Memory(Arc<SimplePager<MemoryVfs>>)
In-memory VFS backend (:memory: databases).
IoUring(Arc<SimplePager<IoUringVfs>>)
Linux io_uring VFS backend (file-backed databases on Linux).
Unix(Arc<SimplePager<UnixVfs>>)
Unix filesystem VFS backend (file-backed databases on all unix platforms).
Implementations
Sourceimpl PagerBackend
impl PagerBackend
Sourcepub fn is_memory(&self) -> bool
pub fn is_memory(&self) -> bool
Returns true if this backend uses the in-memory VFS (:memory:).
Sourcepub fn is_file_backed(&self) -> bool
pub fn is_file_backed(&self) -> bool
Returns true if this backend uses a file-backed VFS.
Sourcepub fn wal_frame_count(&self) -> usize
pub fn wal_frame_count(&self) -> usize
Number of frames currently in the WAL for this pager.
Sourcepub fn published_snapshot(&self) -> PagerPublishedSnapshot
pub fn published_snapshot(&self) -> PagerPublishedSnapshot
Published pager metadata snapshot for lock-light visibility checks.
Sourcepub fn refresh_published_snapshot(
&self,
cx: &Cx,
) -> Result<PagerPublishedSnapshot>
pub fn refresh_published_snapshot( &self, cx: &Cx, ) -> Result<PagerPublishedSnapshot>
Refresh the pager publication plane from the latest committed state and return the resulting snapshot.
Sourcepub fn published_read_retry_count(&self) -> u64
pub fn published_read_retry_count(&self) -> u64
Number of retries readers have taken while binding a stable published snapshot.