pub struct AntiEntropySession { /* private fields */ }Expand description
Anti-entropy session between two replicas.
Implementations
Sourceimpl AntiEntropySession
impl AntiEntropySession
Sourcepub const fn phase(&self) -> AntiEntropyPhase
pub const fn phase(&self) -> AntiEntropyPhase
Current phase.
Sourcepub fn exchange_tips(
&mut self,
local: ReplicaTip,
remote: ReplicaTip,
) -> Result<()>
pub fn exchange_tips( &mut self, local: ReplicaTip, remote: ReplicaTip, ) -> Result<()>
Step 1: Set local and remote tips.
Sourcepub fn compute_missing(
&mut self,
local_objects: &BTreeSet<ObjectId>,
remote_objects: &BTreeSet<ObjectId>,
) -> Result<&MissingObjects>
pub fn compute_missing( &mut self, local_objects: &BTreeSet<ObjectId>, remote_objects: &BTreeSet<ObjectId>, ) -> Result<&MissingObjects>
Step 2: Compute missing objects from local and remote object sets.
Sourcepub fn objects_to_request(&self) -> Option<&BTreeSet<ObjectId>>
pub fn objects_to_request(&self) -> Option<&BTreeSet<ObjectId>>
Step 3: Return the set of object IDs we need symbols for.
Sourcepub fn record_decoded(&mut self, object_id: ObjectId) -> Result<()>
pub fn record_decoded(&mut self, object_id: ObjectId) -> Result<()>
Step 4: Record that we received enough symbols and decoded an object.
Sourcepub const fn is_converged(&self) -> bool
pub const fn is_converged(&self) -> bool
Check if the session has converged.