CommitCapsuleIndexSource

Trait CommitCapsuleIndexSource 

pub trait CommitCapsuleIndexSource {
    // Required method
    fn updates_for_commit(
        &self,
        commit_seq: u64,
        capsule_object_id: ObjectId,
    ) -> Result<Vec<(PageNumber, VersionPointer)>>;
}
Source of per-commit page-version updates recoverable from commit capsules.

Required Methods

fn updates_for_commit( &self, commit_seq: u64, capsule_object_id: ObjectId, ) -> Result<Vec<(PageNumber, VersionPointer)>>

Return all page updates encoded by a commit capsule.

Errors

Returns an error when the capsule cannot be decoded or verified.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors