pub struct ReplicationSender { /* private fields */ }Expand description
Replication sender state machine.
Implementations
Sourceimpl ReplicationSender
impl ReplicationSender
Sourcepub const fn state(&self) -> SenderState
pub const fn state(&self) -> SenderState
Current state.
Sourcepub fn prepare(
&mut self,
page_size: u32,
pages: &mut [PageEntry],
config: SenderConfig,
) -> Result<()>
pub fn prepare( &mut self, page_size: u32, pages: &mut [PageEntry], config: SenderConfig, ) -> Result<()>
Transition from IDLE to ENCODING: prepare a changeset for streaming.
Errors
Returns error if not in IDLE state, pages are empty, or symbol size invalid.
Sourcepub fn start_streaming(&mut self) -> Result<()>
pub fn start_streaming(&mut self) -> Result<()>
Sourcepub fn next_packet(&mut self) -> Result<Option<ReplicationPacket>>
pub fn next_packet(&mut self) -> Result<Option<ReplicationPacket>>
Generate the next replication packet in the stream.
Returns None when all shards have been fully streamed (ISI limit reached).
Errors
Returns error if not in STREAMING state.
Sourcepub fn acknowledge_complete(&mut self) -> Result<()>
pub fn acknowledge_complete(&mut self) -> Result<()>
Acknowledge completion from receiver: stop streaming and transition to COMPLETE.
Errors
Returns error if not in STREAMING state.